# -*- coding: utf-8 -*-
# @Time : 2020-06-05 09:26
# @Author : xzr
# @File : translation.py
# @Software: PyCharm
# @Contact : xzregg@gmail.com
# @Desc :

from django.utils.translation import gettext_lazy as _